# Definition:
  This application is a implementation of Kaucher Interval Arithmetic. This way of calculate express real numbers in interval numbers.
  See the references for more details and the used theory for this implementation.

# How to Install
 - This a module python, just execute "sudo python setup.py install"

# Authors:
- Dirceu Maraschin Jr. @dirceumaraschin
- Lucas Mendes Tortelli @lmtortelli

# Dependencies
- Automatic Installing
[FENV](https://github.com/ldo/pyfenv)
- numpy >= 1.13.1.0
- enum34


# References

[1] Kaucher, Edgar. "Interval analysis in the extended interval space IR." Fundamentals of Numerical Computation (Computer-Oriented Numerical Analysis). Springer Vienna, 1980. 33-49.

[2] Kaucher, Edgar W., and Willard L. Miranker. Self-validating numerics for function space problems: Computation with guarantees for differential and integral equations. Vol. 9. Elsevier, 2014.

[3] Moore, Ramon E. Interval analysis. Vol. 4. Englewood Cliffs: Prentice-Hall, 1966.
